@@ -38,10 +38,10 @@ bmap(
 	struct xfs_btree_block	*block;
 	xfs_fsblock_t		bno;
 	xfs_fileoff_t		curoffset;
-	xfs_dinode_t		*dip;
+	struct xfs_dinode	*dip;
 	xfs_fileoff_t		eoffset;
 	xfs_bmbt_rec_t		*ep;
-	xfs_dinode_fmt_t	fmt;
+	enum xfs_dinode_fmt	fmt;
 	int			fsize;
 	xfs_bmbt_key_t		*kp;
 	int			n;
@@ -62,7 +62,7 @@ bmap(
 	n = 0;
 	eoffset = offset + len - 1;
 	curoffset = offset;
-	fmt = (xfs_dinode_fmt_t)XFS_DFORK_FORMAT(dip, whichfork);
+	fmt = (enum xfs_dinode_fmt)XFS_DFORK_FORMAT(dip, whichfork);
 	typ = whichfork == XFS_DATA_FORK ? TYP_BMAPBTD : TYP_BMAPBTA;
 	ASSERT(typtab[typ].typnm == typ);
 	ASSERT(fmt == XFS_DINODE_FMT_LOCAL || fmt == XFS_DINODE_FMT_EXTENTS ||
@@ -121,20 +121,20 @@ bmap(
 
 static int
 bmap_f(
-	int		argc,
-	char		**argv)
+	int			argc,
+	char			**argv)
 {
-	int		afork = 0;
-	bmap_ext_t	be;
-	int		c;
-	xfs_fileoff_t	co, cosave;
-	int		dfork = 0;
-	xfs_dinode_t	*dip;
-	xfs_fileoff_t	eo;
-	xfs_filblks_t	len;
-	int		nex;
-	char		*p;
-	int		whichfork;
+	int			afork = 0;
+	bmap_ext_t		be;
+	int			c;
+	xfs_fileoff_t		co, cosave;
+	int			dfork = 0;
+	struct xfs_dinode	*dip;
+	xfs_fileoff_t		eo;
+	xfs_filblks_t		len;
+	int			nex;
+	char			*p;
+	int			whichfork;
 
 	if (iocur_top->ino == NULLFSINO) {
 		dbprintf(_("no current inode\n"));
