@@ -52,7 +52,7 @@ const field_t	inode_crc_hfld[] = {
 };
 
 /* XXX: fix this up! */
-#define	OFF(f)	bitize(offsetof(xfs_dinode_t, di_ ## f))
+#define	OFF(f)	bitize(offsetof(struct xfs_dinode, di_ ## f))
 const field_t	inode_flds[] = {
 	{ "core", FLDT_DINODE_CORE, OI(OFF(magic)), C1, 0, TYP_NONE },
 	{ "next_unlinked", FLDT_AGINO, OI(OFF(next_unlinked)), C1, 0,
@@ -74,7 +74,7 @@ const field_t	inode_crc_flds[] = {
 };
 
 
-#define	COFF(f)	bitize(offsetof(xfs_dinode_t, di_ ## f))
+#define	COFF(f)	bitize(offsetof(struct xfs_dinode, di_ ## f))
 const field_t	inode_core_flds[] = {
 	{ "magic", FLDT_UINT16X, OI(COFF(magic)), C1, 0, TYP_NONE },
 	{ "mode", FLDT_UINT16O, OI(COFF(mode)), C1, 0, TYP_NONE },
@@ -247,10 +247,10 @@ fp_dinode_fmt(
 
 static int
 inode_a_bmbt_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(bitoffs(startoff) == 0);
 	ASSERT(obj == iocur_top->data);
@@ -263,10 +263,10 @@ inode_a_bmbt_count(
 
 static int
 inode_a_bmx_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(bitoffs(startoff) == 0);
 	ASSERT(obj == iocur_top->data);
@@ -280,10 +280,10 @@ inode_a_bmx_count(
 
 static int
 inode_a_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(startoff == 0);
 	dip = obj;
@@ -292,11 +292,11 @@ inode_a_count(
 
 static int
 inode_a_offset(
-	void		*obj,
-	int		startoff,
-	int		idx)
+	void			*obj,
+	int			startoff,
+	int			idx)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(startoff == 0);
 	ASSERT(idx == 0);
@@ -307,10 +307,10 @@ inode_a_offset(
 
 static int
 inode_a_sfattr_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(bitoffs(startoff) == 0);
 	ASSERT(obj == iocur_top->data);
@@ -328,7 +328,7 @@ inode_a_size(
 	int				idx)
 {
 	struct xfs_attr_shortform	*asf;
-	xfs_dinode_t			*dip;
+	struct xfs_dinode		*dip;
 
 	ASSERT(startoff == 0);
 	ASSERT(idx == 0);
@@ -349,10 +349,10 @@ inode_a_size(
 
 static int
 inode_core_nlinkv1_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dic;
+	struct xfs_dinode	*dic;
 
 	ASSERT(startoff == 0);
 	ASSERT(obj == iocur_top->data);
@@ -362,10 +362,10 @@ inode_core_nlinkv1_count(
 
 static int
 inode_core_nlinkv2_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dic;
+	struct xfs_dinode	*dic;
 
 	ASSERT(startoff == 0);
 	ASSERT(obj == iocur_top->data);
@@ -375,10 +375,10 @@ inode_core_nlinkv2_count(
 
 static int
 inode_core_onlink_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dic;
+	struct xfs_dinode	*dic;
 
 	ASSERT(startoff == 0);
 	ASSERT(obj == iocur_top->data);
@@ -388,10 +388,10 @@ inode_core_onlink_count(
 
 static int
 inode_core_projid_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dic;
+	struct xfs_dinode	*dic;
 
 	ASSERT(startoff == 0);
 	ASSERT(obj == iocur_top->data);
@@ -462,11 +462,11 @@ inode_size(
 
 static int
 inode_u_offset(
-	void		*obj,
-	int		startoff,
-	int		idx)
+	void			*obj,
+	int			startoff,
+	int			idx)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(startoff == 0);
 	ASSERT(idx == 0);
@@ -476,10 +476,10 @@ inode_u_offset(
 
 static int
 inode_u_bmbt_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(bitoffs(startoff) == 0);
 	ASSERT(obj == iocur_top->data);
@@ -490,10 +490,10 @@ inode_u_bmbt_count(
 
 static int
 inode_u_bmx_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(bitoffs(startoff) == 0);
 	ASSERT(obj == iocur_top->data);
@@ -505,10 +505,10 @@ inode_u_bmx_count(
 
 static int
 inode_u_c_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(bitoffs(startoff) == 0);
 	ASSERT(obj == iocur_top->data);
@@ -521,10 +521,10 @@ inode_u_c_count(
 
 static int
 inode_u_dev_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(bitoffs(startoff) == 0);
 	ASSERT(obj == iocur_top->data);
@@ -535,10 +535,10 @@ inode_u_dev_count(
 
 static int
 inode_u_muuid_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(bitoffs(startoff) == 0);
 	ASSERT(obj == iocur_top->data);
@@ -549,10 +549,10 @@ inode_u_muuid_count(
 
 static int
 inode_u_sfdir2_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(bitoffs(startoff) == 0);
 	ASSERT(obj == iocur_top->data);
@@ -565,10 +565,10 @@ inode_u_sfdir2_count(
 
 static int
 inode_u_sfdir3_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(bitoffs(startoff) == 0);
 	ASSERT(obj == iocur_top->data);
@@ -581,11 +581,11 @@ inode_u_sfdir3_count(
 
 int
 inode_u_size(
-	void		*obj,
-	int		startoff,
-	int		idx)
+	void			*obj,
+	int			startoff,
+	int			idx)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(startoff == 0);
 	ASSERT(idx == 0);
@@ -609,10 +609,10 @@ inode_u_size(
 
 static int
 inode_u_symlink_count(
-	void		*obj,
-	int		startoff)
+	void			*obj,
+	int			startoff)
 {
-	xfs_dinode_t	*dip;
+	struct xfs_dinode	*dip;
 
 	ASSERT(bitoffs(startoff) == 0);
 	ASSERT(obj == iocur_top->data);
@@ -633,16 +633,16 @@ inode_u_symlink_count(
  */
 void
 set_cur_inode(
-	xfs_ino_t	ino)
+	xfs_ino_t		ino)
 {
-	xfs_agblock_t	agbno;
-	xfs_agino_t	agino;
-	xfs_agnumber_t	agno;
-	xfs_dinode_t	*dip;
-	int		offset;
-	int		numblks = blkbb;
-	xfs_agblock_t	cluster_agbno;
-	struct xfs_ino_geometry *igeo = M_IGEO(mp);
+	xfs_agblock_t		agbno;
+	xfs_agino_t		agino;
+	xfs_agnumber_t		agno;
+	struct xfs_dinode	*dip;
+	int			offset;
+	int			numblks = blkbb;
+	xfs_agblock_t		cluster_agbno;
+	struct xfs_ino_geometry	*igeo = M_IGEO(mp);
 
 
 	agno = XFS_INO_TO_AGNO(mp, ino);
