@@ -59,15 +59,15 @@
 #include <sys/xattr.h>
 
 /* Zones used in libxfs allocations that aren't in shared header files */
-extern kmem_zone_t *xfs_buf_item_zone;
-extern kmem_zone_t *xfs_ili_zone;
-extern kmem_zone_t *xfs_buf_zone;
-extern kmem_zone_t *xfs_inode_zone;
-extern kmem_zone_t *xfs_trans_zone;
+extern struct kmem_cache *xfs_buf_item_cache;
+extern struct kmem_cache *xfs_ili_cache;
+extern struct kmem_cache *xfs_buf_cache;
+extern struct kmem_cache *xfs_inode_cache;
+extern struct kmem_cache *xfs_trans_cache;
 
 /* fake up iomap, (not) used in xfs_bmap.[ch] */
-#define IOMAP_F_SHARED			0x04
-#define xfs_bmbt_to_iomap(a, b, c, d)	((void) 0)
+#define IOMAP_F_SHARED				0x04
+#define xfs_bmbt_to_iomap(a, b, c, d, e)	((void) 0)
 
 /* CRC stuff, buffer API dependent on it */
 #define crc32c(c,p,l)	crc32c_le((c),(unsigned char const *)(p),(l))
@@ -75,6 +75,8 @@ extern kmem_zone_t *xfs_trans_zone;
 /* fake up kernel's iomap, (not) used in xfs_bmap.[ch] */
 struct iomap;
 
+#define cancel_delayed_work_sync(work) do { } while(0)
+
 #include "xfs_cksum.h"
 
 /*
@@ -467,6 +469,7 @@ void __xfs_buf_mark_corrupt(struct xfs_buf *bp, xfs_failaddr_t fa);
 	typeof(mode) __mode = mode;				\
 	__mode = __mode; /* no set-but-unused warning */	\
 })
+#define xfs_lock_two_inodes(ip0,mode0,ip1,mode1)	((void) 0)
 
 /* space allocation */
 #define XFS_EXTENT_BUSY_DISCARDED	0x01	/* undergoing a discard op. */
