@@ -1,22 +1,10 @@
+// SPDX-License-Identifier: GPL-2.0
 /*
  * Copyright (c) 2000-2001,2005 Silicon Graphics, Inc.
  * All Rights Reserved.
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it would be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write the Free Software Foundation,
- * Inc.,  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <libxfs.h>
+#include "libxfs.h"
 #include "avl.h"
 #include "globals.h"
 #include "agheader.h"
@@ -60,8 +48,8 @@ generate_rtinfo(xfs_mount_t	*mp,
 		xfs_rtword_t	*words,
 		xfs_suminfo_t	*sumcompute)
 {
-	xfs_drtbno_t	extno;
-	xfs_drtbno_t	start_ext;
+	xfs_rtblock_t	extno;
+	xfs_rtblock_t	start_ext;
 	int		bitsperblock;
 	int		bmbno;
 	xfs_rtword_t	freebit;
@@ -133,7 +121,7 @@ generate_rtinfo(xfs_mount_t	*mp,
 int
 check_summary(xfs_mount_t *mp)
 {
-	xfs_drfsbno_t	bno;
+	xfs_rfsblock_t	bno;
 	xfs_suminfo_t	*csp;
 	xfs_suminfo_t	*fsp;
 	int		log;
@@ -165,26 +153,27 @@ check_summary(xfs_mount_t *mp)
  * instead of the realtime bitmap file
  */
 void
-process_rtbitmap(xfs_mount_t	*mp,
-		xfs_dinode_t	*dino,
-		blkmap_t	*blkmap)
+process_rtbitmap(
+	struct xfs_mount	*mp,
+	struct xfs_dinode	*dino,
+	blkmap_t		*blkmap)
 {
-	int		error;
-	int		bit;
-	int		bitsperblock;
-	int		bmbno;
-	int		end_bmbno;
-	xfs_dfsbno_t	bno;
-	xfs_buf_t	*bp;
-	xfs_drtbno_t	extno;
-	int		i;
-	int		len;
-	int		log;
-	int		offs;
-	int		prevbit;
-	int		start_bmbno;
-	int		start_bit;
-	xfs_rtword_t	*words;
+	int			error;
+	int			bit;
+	int			bitsperblock;
+	int			bmbno;
+	int			end_bmbno;
+	xfs_fsblock_t		bno;
+	struct xfs_buf		*bp;
+	xfs_rtblock_t		extno;
+	int			i;
+	int			len;
+	int			log;
+	int			offs;
+	int			prevbit;
+	int			start_bmbno;
+	int			start_bit;
+	xfs_rtword_t		*words;
 
 	ASSERT(mp->m_rbmip == NULL);
 
@@ -199,15 +188,15 @@ process_rtbitmap(xfs_mount_t	*mp,
 	for (bmbno = 0; bmbno < end_bmbno; bmbno++) {
 		bno = blkmap_get(blkmap, bmbno);
 
-		if (bno == NULLDFSBNO) {
+		if (bno == NULLFSBLOCK) {
 			do_warn(_("can't find block %d for rtbitmap inode\n"),
 					bmbno);
 			error = 1;
 			continue;
 		}
-		bp = libxfs_readbuf(mp->m_dev, XFS_FSB_TO_DADDR(mp, bno),
-				XFS_FSB_TO_BB(mp, 1), NULL);
-		if (!bp) {
+		error = -libxfs_buf_read(mp->m_dev, XFS_FSB_TO_DADDR(mp, bno),
+				XFS_FSB_TO_BB(mp, 1), 0, NULL, &bp);
+		if (error) {
 			do_warn(_("can't read block %d for rtbitmap inode\n"),
 					bmbno);
 			error = 1;
@@ -234,7 +223,7 @@ process_rtbitmap(xfs_mount_t	*mp,
 				prevbit = 0;
 			}
 		}
-		libxfs_putbuf(bp);
+		libxfs_buf_relse(bp);
 		if (extno == mp->m_sb.sb_rextents)
 			break;
 	}
@@ -250,26 +239,27 @@ process_rtbitmap(xfs_mount_t	*mp,
  * copy the real-time summary file data into memory
  */
 void
-process_rtsummary(xfs_mount_t	*mp,
-		xfs_dinode_t	*dino,
-		blkmap_t	*blkmap)
+process_rtsummary(
+	xfs_mount_t		*mp,
+	struct xfs_dinode	*dino,
+	blkmap_t		*blkmap)
 {
-	xfs_fsblock_t	bno;
-	xfs_buf_t	*bp;
-	char		*bytes;
-	int		sumbno;
+	xfs_fsblock_t		bno;
+	struct xfs_buf		*bp;
+	char			*bytes;
+	int			sumbno;
 
 	for (sumbno = 0; sumbno < blkmap->count; sumbno++) {
 		bno = blkmap_get(blkmap, sumbno);
-		if (bno == NULLDFSBNO) {
+		if (bno == NULLFSBLOCK) {
 			do_warn(_("block %d for rtsummary inode is missing\n"),
 					sumbno);
 			error++;
 			continue;
 		}
-		bp = libxfs_readbuf(mp->m_dev, XFS_FSB_TO_DADDR(mp, bno),
-				XFS_FSB_TO_BB(mp, 1), NULL);
-		if (!bp) {
+		error = -libxfs_buf_read(mp->m_dev, XFS_FSB_TO_DADDR(mp, bno),
+				XFS_FSB_TO_BB(mp, 1), 0, NULL, &bp);
+		if (error) {
 			do_warn(_("can't read block %d for rtsummary inode\n"),
 					sumbno);
 			error++;
@@ -278,7 +268,7 @@ process_rtsummary(xfs_mount_t	*mp,
 		bytes = bp->b_un.b_addr;
 		memmove((char *)sumfile + sumbno * mp->m_sb.sb_blocksize, bytes,
 			mp->m_sb.sb_blocksize);
-		libxfs_putbuf(bp);
+		libxfs_buf_relse(bp);
 	}
 }
 #endif
